# Authentication

::: questra_authentication.authentication.ClientInterface
    options:
      show_source: false
      heading_level: 2

::: questra_authentication.authentication.OidcConfig
    options:
      show_source: false
      heading_level: 2

::: questra_authentication.authentication.OidcDiscoveryClient
    options:
      show_source: false
      heading_level: 2

::: questra_authentication.authentication.OAuth2Credential
    options:
      show_source: false
      heading_level: 2

::: questra_authentication.authentication.OAuth2ServiceCredential
    options:
      show_source: false
      heading_level: 2
      show_docstring_attributes: true

::: questra_authentication.authentication.OAuth2InteractiveUserCredential
    options:
      show_source: false
      heading_level: 2
      show_docstring_attributes: true

::: questra_authentication.authentication.OAuth2Authentication
    options:
      show_source: false
      heading_level: 2
